@@ -87,6 +87,9 @@ class ClientLogo(BaseModel):
 class User(BaseModel):
     email = EmailField(api_name='Email', required=True)
     kyc_level = CharField(api_name='KYCLevel', choices=constants.KYC_LEVEL, default=constants.KYC_LEVEL.light)
+    terms_and_conditions_accepted = BooleanField(api_name='TermsAndConditionsAccepted')
+    terms_and_conditions_accepted_date = DateTimeField(api_name='TermsAndConditionsAcceptedDate')
+    user_category = CharField(api_name='UserCategory')
 
     def fixed_kwargs(self):
         return {"user_id": self.id}
